@@ -7,3 +7,6 @@ knitr::opts_chunk$set(
 ## ----setup---------------------------------------------------------------
 library(gradeR)
 
+## ---- out.width = "400px", include=TRUE, fig.align="center", echo=F------
+knitr::include_graphics("example/distributed_assignment/screenshot.png")
+
